# pyqdpx/__init__.py

from .pyqdpx import QDPX, User, Code, Source

# You can also add package-level metadata here if needed
__version__ = "0.1.0"
__author__ = "Pethő Gergely"
__email__ = "petho.gergely@etk.unideb.hu"